@@ -23,9 +23,10 @@
 #include <pyglib-python-compat.h>
 
 #include "pygi-array.h"
-#include "pygi-private.h"
+#include "pygi-info.h"
 #include "pygi-marshal-cleanup.h"
 #include "pygi-basictype.h"
+#include "pygi-util.h"
 
 /* Needed for _pygi_marshal_cleanup_from_py_interface_struct_gvalue hack */
 #include "pygi-struct-marshal.h"
