@@ -20,8 +20,12 @@
 #include "pygi-value.h"
 #include "pygi-struct.h"
 #include "pyglib-python-compat.h"
-#include "pygobject-private.h"
+#include "pygobject-object.h"
 #include "pygtype.h"
+#include "pygenum.h"
+#include "pygpointer.h"
+#include "pygboxed.h"
+#include "pygflags.h"
 #include "pygparamspec.h"
 
 GIArgument
